﻿using System;
using System.Collections.Generic;
using System.Data;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using System.Xml.Linq;

namespace C1WebAPI.Models
{
    public static class Employees
    {
        private static DataSet _dataset;
        private static string[] _categories;
        private static object _lockObj = new object();

        public static DataSet DataSet
        {
            get
            {
                EnsureInit();
                return _dataset;
            }
        }

        public static string[] Category
        {
            get
            {
                EnsureInit();
                return _categories;
            }
        }

        private static void EnsureInit()
        {
            if (_dataset == null)
            {
                lock (_lockObj)
                {
                    if (_dataset == null)
                    {
                        InitDataSet();
                    }
                }
            }
        }

        private static void InitDataSet()
        {
            _dataset = new DataSet();
            var doc = XElement.Load(Path.Combine(Directory.GetCurrentDirectory(), @"wwwroot/Content/Employee.xml"));
            foreach (var employee in doc.Elements("Employee"))
            {
                var category = employee.Element("Category").Value;
                var table = GetEmployeesDataTable(category);
                var row = table.NewRow();
                row["Category"] = category;
                row["LastName"] = employee.Element("LastName").Value;
                row["FirstName"] = employee.Element("FirstName").Value;
                
                table.Rows.Add(row);
            }

            _categories = _dataset.Tables.OfType<DataTable>().Select(t => t.TableName).ToArray();
        }

        private static DataTable GetEmployeesDataTable(string name)
        {
            if (_dataset.Tables.Contains(name))
                return _dataset.Tables[name];

            var table = CreateEmployeesDataTable(name);
            _dataset.Tables.Add(table);
            return table;
        }

        private static DataTable CreateEmployeesDataTable(string name)
        {
            var table = new DataTable(name);
            table.Columns.Add("LastName");
            table.Columns.Add("FirstName");
            table.Columns.Add("Category");           
            return table;
        }
    }
}
